nikola.plugins.template package
===============================

.. automodule:: nikola.plugins.template
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

nikola.plugins.template.jinja module
------------------------------------

.. automodule:: nikola.plugins.template.jinja
   :members:
   :undoc-members:
   :show-inheritance:

nikola.plugins.template.mako module
-----------------------------------

.. automodule:: nikola.plugins.template.mako
   :members:
   :undoc-members:
   :show-inheritance:

